==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyRindexClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyRindexClass

// class file dependencies
// @dep_class afd23cc39d2bd879 gnu_xml_xpath_XPathParser__24YyRindexClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyRindexClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyRindexClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct {
	_jc_short_array	*yyRindex;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods	gnu_xml_xpath_XPathParser__24YyRindexClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs	gnu_xml_xpath_XPathParser__24YyRindexClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyRindexClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyRindexClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyRindexClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyRindexClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyRindexClass

// class file dependencies
// @dep_class afd23cc39d2bd879 gnu_xml_xpath_XPathParser__24YyRindexClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyRindexClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyRindexClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct {
	_jc_short_array	*yyRindex;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vmethods	gnu_xml_xpath_XPathParser__24YyRindexClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_refs	gnu_xml_xpath_XPathParser__24YyRindexClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyRindexClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyRindexClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyRindexClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyRindexClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyRindexClass_H_ */
